@@ -24,7 +24,7 @@
     (scss:make-document-interface
      sdom:tag-name
      sdom:parent-node
-     sdom:prev-sibling
+     sdom:previous-sibling
 
      sdom:get-attribute
      (lambda (node) (sdom:get-attribute node "class"))
