@@ -142,7 +142,7 @@
 	(and (eq? (car x) 'class)
 	     (case (length x)
 	       ((2) (cadr x))
-	       ((3) (and (if recurse (selector? (cadr x)) #t)
+	       ((3) (and (if recurse (selector? (cadr x) #t) #t)
 			 (symbol? (caddr x)) 
 			 (caddr x)))
 	       (else #f)))
@@ -198,7 +198,7 @@
     (if (list? x)
 	(and (= (length x) 3) 
 	     (eq? (car x) 'attrib) 
-	     (if recurse (selector? (cadr x)) #t) 
+	     (if recurse (selector? (cadr x) #t) #t) 
 	     (caddr x))
 	(let* ((str (symbol->string x))
 	       (start (string-index str #\[))
@@ -314,7 +314,7 @@
 	       (simple-selector-match? selection-context (cadr sel) sib)
 	       (simple-selector-match? selection-context (caddr sel) node)))
 	(and (simple-selector-match? selection-context (cadr sel) node)
-	     (simple-selector-match? seletion-context (caddr sel) node))))
+	     (simple-selector-match? selection-context (caddr sel) node))))
   
   (define (path-selector-match? selection-context sel node)
     (define di (scss:selection-context-document-interface selection-context))
@@ -322,8 +322,10 @@
       (define (f y) (equal? (scss:name di y) s))
       (let loop ((n x)) (and n (or (and (f n) n) (loop (scss:parent di n))))))
     (let* ((csel (car sel))
-	   (r (if (combinator? csel #f)
-		  (combinator-selector-match? selection-context csel node)
+	   (combinator (combinator? csel #f))
+	   (r (if combinator
+		  (combinator-selector-match? 
+		   selection-context csel combinator node)
 		  (simple-selector-match? selection-context csel node))))
       (if (null? (cdr sel)) 
 	  r
@@ -550,11 +552,6 @@
   (define (scss:select-values context selector)
     (select-values context selector))
   
-  (define (get-prop-entry prop) (hashtable-ref property-hash-table prop #f))
-  (define (get-default-prop-value prop)
-    (let ((entry (get-prop-entry prop)))
-      (and entry (css-property:default entry))))
-  
   (define (scss:get-default-value prop)
     (verify-arg-types "scss:get-default-value" (list symbol?) (list prop) 1)
     (get-default-prop-value prop))
